@@ -118,6 +118,11 @@ sub authenticate {
 	my $attribute = $self->attribute;
 	my $res = $self->search($uid, [$attribute]);
 
+	unless($res->count) {
+		warn "Invalid username\n";
+		return undef;
+	}
+
 	undef $uid;
 	foreach my $entry ($res->entries) {
 		my $dn = $entry->dn;
